@@ -32,7 +32,8 @@ i_reflectance = function(x, nwavelengths = NULL, nsample = NULL, enforce01 = FAL
     }
 
     if(is.data.frame(x)) {
-        x = as.matrix(x)     ## should convert factors to character
+        ## Assumes that `as.matrix` converts factors to character
+        x = as.matrix(x)
         mode(x) = "numeric"
     }
 
@@ -64,14 +65,16 @@ i_reflectance = function(x, nwavelengths = NULL, nsample = NULL, enforce01 = FAL
 #'
 #' \code{i_names} constructs a sample name vector in the appropriate format
 #'
-#' @param x vector of labels. numeric or character
+#' @param x vector of labels. Should be character. If numeric, a prefix will be added
 #' @param nsample Integer of expected number of samples.
 #'                If NULL (default) checking is skipped.
-#' @return vector of sample names
+#' @param prefix String to use as prefix in case an element of x is numeric.
+#'               Defaults to "spec_"
+#' @return vector of sample names coerced to character
 #'
 #' @keywords internal
 #' @author Jose Eduardo Meireles
-i_names = function(x, nsample = NULL){
+i_names = function(x, nsample = NULL, prefix = "spec_"){
 
     if( ! is.null(dim(x)) ){
         stop("Sample names must be one dimensional")
@@ -83,6 +86,22 @@ i_names = function(x, nsample = NULL){
         stop("The length of x must be the same as nsample")
     }
 
+    ## In case x has numeric elements...
+    n = which(suppressWarnings(!is.na(as.numeric(x))))
+
+    ## ...prepend them with `prefix`...
+    if(length(n) > 0){
+
+        ## while ensuring that `prefix` is a valid char
+        if( suppressWarnings(!is.na(as.numeric(prefix))) ||
+            is.null(prefix) ||
+            is.na(prefix) ){
+            prefix = "spec_"
+        }
+
+        x[n] = paste(prefix, x[n], sep = "")
+    }
+
     as.character(x)
 }
 
@@ -220,7 +239,7 @@ spectra = function(reflectance,
                                            nsample      = spl_l,
                                            enforce01    = enforce01),
               wavelengths  = i_wavelengths(wavelengths),
-              names        = i_names(names),
+              names        = i_names(names, prefix = NULL),     ## relies of the default prefix inside i_names
               meta         = i_meta(NULL, nsample = spl_l, ...) ## *** Ideally i_meta(meta, nsample = spl_l, ...)
               )
 
